@@ -390,7 +390,7 @@ neuromuscularProfilePlotOther <- function(displacement, l.context, l.mass, smoot
 	}
 
 	cols <- c("red","green","blue")
-	plot(forceFirst, type="n", xlab=paste(translate("time"),"(ms)"), ylab=paste(translate("Force"),"(N)"), 
+	plot(forceFirst, type="n", xlab=paste(translateToPrint("time"),"(ms)"), ylab=paste(translateToPrint("Force"),"(N)"), 
 	     xlim=c(0,maximumLength), ylim=c(minimumForce, maximumForce))
 
 	#align curves to the right, add NAs at start
@@ -423,9 +423,9 @@ neuromuscularProfileWriteData <- function(npj, outputData1)
 	df <- data.frame(rbind(jump1,jump2,jump3))
 	colnames(df) <- c(paste("e1.",names(npj[[1]]$e1),sep=""), names(npj[[1]]$c))
 	rownames(df) <- c(
-			  paste(translate("jump"),npj[[1]]$l.context$numJump), 
-			  paste(translate("jump"),npj[[2]]$l.context$numJump),
-			  paste(translate("jump"),npj[[3]]$l.context$numJump))
+			  paste(translateToPrint("jump"),npj[[1]]$l.context$numJump), 
+			  paste(translateToPrint("jump"),npj[[2]]$l.context$numJump),
+			  paste(translateToPrint("jump"),npj[[3]]$l.context$numJump))
 	print(df)
 
 	write.csv(df, outputData1, quote=FALSE)
