@@ -628,7 +628,7 @@ public class Constants
 		//P = mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tt;
 		"P = " + Catalog.GetString("mass") + " * g * ( " + 
 		Catalog.GetString("falling height") + " + 1.226 * " + Catalog.GetString("flight time") + " ^ 2 ) / " + 
-		Catalog.GetString("total_time") +
+		Catalog.GetString("contact time") +
 		"\n\n" +
 		Catalog.GetString("Jumps without TC: Lewis Peak Power 1974 (W)") + 
 		"\n\n" +
@@ -826,6 +826,7 @@ public class Constants
 		"Accel.",
 		"Force",
 		"Power",
+		"Average Power",
 		"Peak Power",
 		"Distance",
 		"Time to Peak Power",
@@ -856,8 +857,11 @@ public class Constants
 	 * written here in order to be translated
 	 * Attention: this will be separated by ';', then no ';' sign can be here
 	 * No "\n" can be here also
+	 * No "'" can be here also. eg d'inèrcia on catalan
 	 * if translators add one, it will be converted to ','
 	 * if translators add a "\n", it will be converted to " "
+	 * if translators add a "'", it will be converted to ' '
+	 *
 	 * check that this list has same elements than above list
 	 */
 	public static string [] EncoderTranslatedWords = {
@@ -868,6 +872,7 @@ public class Constants
 		Catalog.GetString("Accel."),
 		Catalog.GetString("Force"),
 		Catalog.GetString("Power"),
+		Catalog.GetString("Average Power"),
 		Catalog.GetString("Peak Power"),
 		Catalog.GetString("Distance"),
 		Catalog.GetString("Time to Peak Power"),
