@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2014-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -185,8 +185,7 @@ public class ExecuteAutoSQL
 		if(str == null || str == "")
 			return new List<int>();
 
-		Log.WriteLine("SerieIDsFromStr");
-		Log.WriteLine(str);
+		LogB.Information("SerieIDsFromStr", str);
 		string [] strFull = str.Split(new char[] {':'});
 		
 		List <int>l = new List <int>();
