@@ -20,6 +20,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic; //List<T>
 using Gtk;
 using Gdk;
 using Glade;
@@ -50,7 +51,27 @@ public class EncoderConfigurationWindow
 	[Widget] Gtk.Label label_count;
 
 	[Widget] Gtk.TextView textview;
-	[Widget] Gtk.Box hbox_d;
+
+	//diameter when there's no inertia
+	[Widget] Gtk.Box hbox_d; 
+	[Widget] Gtk.SpinButton spin_d;
+
+	//diameters whent there's inertia (is plural because there can be many anchorages)
+	[Widget] Gtk.Box vbox_d; 
+	[Widget] Gtk.Box hbox_list_d;
+	[Widget] Gtk.ComboBox combo_d_num;
+	[Widget] Gtk.SpinButton spin_d_0;
+	[Widget] Gtk.SpinButton spin_d_1;
+	[Widget] Gtk.SpinButton spin_d_2;
+	[Widget] Gtk.SpinButton spin_d_3;
+	[Widget] Gtk.SpinButton spin_d_4;
+	[Widget] Gtk.SpinButton spin_d_5;
+	[Widget] Gtk.SpinButton spin_d_6;
+	[Widget] Gtk.SpinButton spin_d_7;
+	[Widget] Gtk.SpinButton spin_d_8;
+	[Widget] Gtk.SpinButton spin_d_9;
+
+
 	[Widget] Gtk.Box hbox_D;
 	[Widget] Gtk.Box hbox_angle_push;
 	[Widget] Gtk.Box hbox_angle_weight;
@@ -59,7 +80,6 @@ public class EncoderConfigurationWindow
 	[Widget] Gtk.Box hbox_inertia_length;
 	[Widget] Gtk.Box vbox_inertia_calcule;
 
-	[Widget] Gtk.SpinButton spin_d;
 	[Widget] Gtk.SpinButton spin_D;
 	[Widget] Gtk.SpinButton spin_angle_push;
 	[Widget] Gtk.SpinButton spin_angle_weight;
@@ -137,9 +157,11 @@ public class EncoderConfigurationWindow
 
 
 		EncoderConfigurationWindowBox.initializeList(ec.type, ec.has_inertia, ec.rotaryFrictionOnAxis, ec.position);
+	
+		EncoderConfigurationWindowBox.create_list_d_spinbutton();
 		
 		EncoderConfigurationWindowBox.putValuesStoredPreviously(
-				ec.d, ec.D, ec.anglePush, ec.angleWeight, 
+				ec.d, ec.list_d, ec.D, ec.anglePush, ec.angleWeight, 
 				ec.inertiaMachine, ec.extraWeightGrams, ec.extraWeightLength);
 		
 
@@ -248,7 +270,9 @@ public class EncoderConfigurationWindow
 		tb1.Text = "[" + ec.code + "]\n" + ec.text;
 		textview.Buffer = tb1;
 		
-		hbox_d.Visible = ec.has_d;
+		hbox_d.Visible = (ec.has_d && ! ec.has_inertia);
+		vbox_d.Visible = (ec.has_d && ec.has_inertia);
+
 		hbox_D.Visible = ec.has_D;
 		hbox_angle_push.Visible = ec.has_angle_push;
 		hbox_angle_weight.Visible = ec.has_angle_weight;
@@ -264,11 +288,20 @@ public class EncoderConfigurationWindow
 			on_button_encoder_capture_inertial_show_clicked (new object(), new EventArgs());
 	}
 	
-	private void putValuesStoredPreviously(double d, double D, int anglePush, int angleWeight, 
+	private void putValuesStoredPreviously(double d, List<double> list_d, double D, int anglePush, int angleWeight, 
 			int inertia, int extraWeightGrams, double extraWeightLength) 
 	{
 		if(d != -1)
 			spin_d.Value = d;
+		if(list_d != null && list_d.Count > 0) {
+			//when there's 1 value in list_d, first value (0) in combo should be selected
+			combo_d_num.Active = list_d.Count -1; //this will perform a reset on spinbuttons
+		
+			int i = 0;
+			foreach(Gtk.SpinButton sp in hbox_list_d.Children)
+				sp.Value = list_d[i ++];
+		}
+
 		if(D != -1)
 			spin_D.Value = D;
 		if(anglePush != -1)
@@ -282,6 +315,90 @@ public class EncoderConfigurationWindow
 		spin_inertia_length.Value = extraWeightLength;
 	}
 	
+	private void create_list_d_spinbutton () {
+		/*
+		 * adjustment definition:
+		 * initial value
+		 * minimum value
+		 * maximum value
+		 * increment for a single step (e.g. one click on an arrow)
+		 * increment for a page-up or page-down keypress
+		 * page size (using any value other than 0 for this parameter is deprecated) 
+		 * 
+		 * spinbutton creation (adjustment, climb rate, decimals)
+		 */
+		spin_d_0 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_1 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_2 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_3 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_4 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_5 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_6 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_7 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_8 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+		spin_d_9 = new Gtk.SpinButton(new Adjustment(4, .5f, 80.0f, .01f, 10.0f, 0f), 1, 2);
+
+		combo_d_num.Active = 0;
+		
+		reset_hbox_list_d (1);
+	}
+
+	private void on_combo_d_num_changed (object o, EventArgs args) {
+		reset_hbox_list_d(Convert.ToInt32(UtilGtk.ComboGetActive(combo_d_num)));
+	}
+	
+	void reset_hbox_list_d (int colsNum) 
+	{
+		foreach(Gtk.SpinButton sp in hbox_list_d.Children)
+			hbox_list_d.Remove(sp);
+
+		for (int i = 0; i < colsNum; i ++) {
+			switch(i) {
+				case 0: 
+					hbox_list_d.PackStart(spin_d_0, false, false, 0);
+					break;
+				case 1: 
+					hbox_list_d.PackStart(spin_d_1, false, false, 0);
+					break;
+				case 2: 
+					hbox_list_d.PackStart(spin_d_2, false, false, 0);
+					break;
+				case 3: 
+					hbox_list_d.PackStart(spin_d_3, false, false, 0);
+					break;
+				case 4: 
+					hbox_list_d.PackStart(spin_d_4, false, false, 0);
+					break;
+				case 5: 
+					hbox_list_d.PackStart(spin_d_5, false, false, 0);
+					break;
+				case 6: 
+					hbox_list_d.PackStart(spin_d_6, false, false, 0);
+					break;
+				case 7: 
+					hbox_list_d.PackStart(spin_d_7, false, false, 0);
+					break;
+				case 8: 
+					hbox_list_d.PackStart(spin_d_8, false, false, 0);
+					break;
+				case 9: 
+					hbox_list_d.PackStart(spin_d_9, false, false, 0);
+					break;
+			}
+		}
+		hbox_list_d.ShowAll();
+	}
+	
+	private List<double> get_list_d	() {
+		List<double> l = new List<double>(); 
+		double d = new double();
+		foreach(Gtk.SpinButton sp in hbox_list_d.Children) {
+			d = (double) sp.Value;
+			l.Add(d);
+		}
+		return l;
+	}
+	
 	/*
 	 * Use this to retrieve values after accept
 	 * do not use to know current encoder configuration
@@ -293,13 +410,20 @@ public class EncoderConfigurationWindow
 		EncoderConfiguration ec = (EncoderConfiguration) list[listCurrent];
 		
 		ec.d = -1;
+		ec.list_d = new List<double>(); 
 		ec.D = -1;
 		ec.anglePush = -1;
 		ec.angleWeight = -1;
 		ec.inertiaMachine = -1;
 		
-		if(ec.has_d)
-			ec.d = (double) spin_d.Value; 
+		if(ec.has_d) {
+			if(ec.has_inertia) {
+				ec.list_d = get_list_d();
+				ec.d = ec.list_d[0]; //selected value is the first
+			}
+			else
+				ec.d = (double) spin_d.Value; 
+		}
 
 		if(ec.has_D)
 			ec.D = (double) spin_D.Value; 
