@@ -577,9 +577,15 @@ public partial class ChronoJumpWindow
 					//cells[3]: massBody
 					//cells[4]: massExtra
 
-					totalMass = Convert.ToDouble(Util.ChangeDecimalSeparator(cells[3])) * 
-						getExercisePercentBodyWeightFromName (exerciseName) / 100.0
-						+ Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4]));
+		
+					//don't show the DisplacedWeight on AVG or SD because there can be many exercises 
+					//(with different exercisePercentBodyWeight) and persons
+					if(cells[0] == "AVG" || cells[0] == "SD")
+						totalMass  = -1; //mark to not be shown
+					else
+						totalMass = Convert.ToDouble(Util.ChangeDecimalSeparator(cells[3])) * 
+							getExercisePercentBodyWeightFromName (exerciseName) / 100.0
+							+ Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4]));
 					
 					LogB.Debug("totalMass:" + totalMass.ToString());
 				}
@@ -889,6 +895,11 @@ public partial class ChronoJumpWindow
 	private void RenderNAnalyze (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+			
+		if(curve.N == "AVG" || curve.N == "SD") {
+			(cell as Gtk.CellRendererText).Markup = "<b>" + Catalog.GetString(curve.N) + "</b>";
+			return;
+		}
 		
 		if(check_encoder_analyze_signal_or_curves.Active && findEccon(false) == "ecS") 
 		{
@@ -916,50 +927,80 @@ public partial class ChronoJumpWindow
 	private void RenderSeries (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = curve.Series;
+
+		if(curve.Series == "NA")
+			(cell as Gtk.CellRendererText).Text = "";
+		else 
+			(cell as Gtk.CellRendererText).Text = curve.Series;
 	}
 
 	private void RenderExercise (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = curve.Exercise;
+		
+		if(curve.Exercise == "NA")
+			(cell as Gtk.CellRendererText).Text = "";
+		else 
+			(cell as Gtk.CellRendererText).Text = curve.Exercise;
 	}
 
 	private void RenderLaterality (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = curve.Laterality;
+		
+		if(curve.Laterality == "NA")
+			(cell as Gtk.CellRendererText).Text = "";
+		else 
+			(cell as Gtk.CellRendererText).Text = curve.Laterality;
+	}
+
+	private void renderBoldIfNeeded(Gtk.CellRenderer cell, EncoderCurve curve, string str)
+	{
+		if(curve.N == "AVG" || curve.N == "SD")
+			(cell as Gtk.CellRendererText).Markup = "<b>" + str + "</b>";
+		else
+			(cell as Gtk.CellRendererText).Text = str;
 	}
 
 	private void RenderExtraWeight (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.ExtraWeight.ToString(),3,0),Convert.ToInt32(curve.ExtraWeight));
+
+		string str = String.Format(UtilGtk.TVNumPrint(curve.ExtraWeight.ToString(),3,0),Convert.ToInt32(curve.ExtraWeight));
+
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderDisplacedWeight (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.DisplacedWeight.ToString(),3,0),Convert.ToInt32(curve.DisplacedWeight));
+		string str = "";
+			
+		//don't show the DisplacedWeight on AVG or SD because there can be many exercises 
+		//(with different exercisePercentBodyWeight) and persons
+		if(curve.DisplacedWeight == -1)	
+			str = "";
+		else
+		       	str = String.Format(UtilGtk.TVNumPrint(curve.DisplacedWeight.ToString(),3,0),Convert.ToInt32(curve.DisplacedWeight));
+		
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderStart (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double myStart = Convert.ToDouble(curve.Start)/1000; //ms->s
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(myStart.ToString(),6,3),myStart); 
+		string str = String.Format(UtilGtk.TVNumPrint(myStart.ToString(),6,3),myStart); 
+		renderBoldIfNeeded(cell, curve, str);
 	}
 	
 	private void RenderDuration (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double myDuration = Convert.ToDouble(curve.Duration)/1000; //ms->s
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(myDuration.ToString(),5,3),myDuration); 
+		string str = String.Format(UtilGtk.TVNumPrint(myDuration.ToString(),5,3),myDuration); 
+		renderBoldIfNeeded(cell, curve, str);
 	}
 	
 	private void RenderHeight (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -977,8 +1018,8 @@ public partial class ChronoJumpWindow
 		else
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(heightToCm,5,1),Convert.ToDouble(heightToCm));
+		string str = String.Format(UtilGtk.TVNumPrint(heightToCm,5,1),Convert.ToDouble(heightToCm));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 	
 	private void RenderMeanSpeed (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -996,8 +1037,8 @@ public partial class ChronoJumpWindow
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
 		//no need of UtilGtk.TVNumPrint, always has 1 digit on left of decimal
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format("{0,8:0.000}",Convert.ToDouble(curve.MeanSpeed));
+		string str = String.Format("{0,8:0.000}",Convert.ToDouble(curve.MeanSpeed));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderMaxSpeed (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -1015,16 +1056,16 @@ public partial class ChronoJumpWindow
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
 		//no need of UtilGtk.TVNumPrint, always has 1 digit on left of decimal
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format("{0,8:0.000}",Convert.ToDouble(curve.MaxSpeed));
+		string str = String.Format("{0,8:0.000}",Convert.ToDouble(curve.MaxSpeed));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 	
 	private void RenderMaxSpeedT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double time = Convert.ToDouble(curve.MaxSpeedT)/1000; //ms->s
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(time.ToString(),5,3),time);
+		string str = String.Format(UtilGtk.TVNumPrint(time.ToString(),5,3),time);
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderMeanPower (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -1041,8 +1082,8 @@ public partial class ChronoJumpWindow
 		else
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MeanPower));
+		string str = String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MeanPower));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderPeakPower (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -1059,23 +1100,23 @@ public partial class ChronoJumpWindow
 		else
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.PeakPower,7,1),Convert.ToDouble(curve.PeakPower));
+		string str = String.Format(UtilGtk.TVNumPrint(curve.PeakPower,7,1),Convert.ToDouble(curve.PeakPower));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderPeakPowerT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double myPPT = Convert.ToDouble(curve.PeakPowerT)/1000; //ms->s
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(myPPT.ToString(),5,3),myPPT);
+		string str = String.Format(UtilGtk.TVNumPrint(myPPT.ToString(),5,3),myPPT);
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderPP_PPT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.PP_PPT,6,1),Convert.ToDouble(curve.PP_PPT));
+		string str = String.Format(UtilGtk.TVNumPrint(curve.PP_PPT,6,1),Convert.ToDouble(curve.PP_PPT));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 	
 	/* end of rendering analyze cols. Following gols are only on capture */
@@ -1094,8 +1135,8 @@ public partial class ChronoJumpWindow
 		else
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.MeanForce,7,1),Convert.ToDouble(curve.MeanForce));
+		string str = String.Format(UtilGtk.TVNumPrint(curve.MeanForce,7,1),Convert.ToDouble(curve.MeanForce));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	private void RenderMaxForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -1112,16 +1153,16 @@ public partial class ChronoJumpWindow
 		else
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.MaxForce,7,1),Convert.ToDouble(curve.MaxForce));
+		string str = String.Format(UtilGtk.TVNumPrint(curve.MaxForce,7,1),Convert.ToDouble(curve.MaxForce));
+		renderBoldIfNeeded(cell, curve, str);
 	}
 	
 	private void RenderMaxForceT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double time = Convert.ToDouble(curve.MaxForceT)/1000; //ms->s
-		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(time.ToString(),5,3),time);
+		string str = String.Format(UtilGtk.TVNumPrint(time.ToString(),5,3),time);
+		renderBoldIfNeeded(cell, curve, str);
 	}
 
 	
