@@ -78,13 +78,14 @@ public class HelpPorts
 	
 		if(UtilAll.IsWindows()) {
 			label_help_info.Text = 
-				Catalog.GetString("If you have problems connecting with Chronopic, ensure you have the <b>driver</b> installed at 'Windows Start Menu / Chronojump / Install Chronopic driver'.") + "\n\n" + 
+				Constants.FindDriverWindows + "\n\n" + 
 				Catalog.GetString("Ports above COM4 may not work.") + "\n" + 
 				Catalog.GetString("If you want a safer port, press:") + "\n" +
 				Catalog.GetString("Force Chronopic to port <b>COM1 - COM4</b>'.");
-			label_help_info.UseMarkup = true;
 		} else
-			label_help_info.Visible = false;
+			label_help_info.Text = Constants.FindDriverOthers; 
+
+		label_help_info.UseMarkup = true;
 
 		label_help_manual.Text = 
 			Catalog.GetString("More information on <b>Chronojump Manual</b>") + "\n" +
