@@ -973,9 +973,8 @@ partial class ChronoJumpWindow
 {
 	//options jumps
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_weight;
-	[Widget] Gtk.Box extra_window_jumps_vbox_fall;
-	[Widget] Gtk.RadioButton extra_window_jumps_radio_dj_fall_predefined;
-	[Widget] Gtk.RadioButton extra_window_jumps_radio_dj_fall_calculate;
+	[Widget] Gtk.Box extra_window_jumps_hbox_fall;
+	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_fall_calculate;
 	[Widget] Gtk.Label extra_window_jumps_label_dj_start_inside;
 	[Widget] Gtk.Label extra_window_jumps_label_dj_start_outside;
 	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_fall;
@@ -983,14 +982,11 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
 	[Widget] Gtk.Label extra_window_jumps_label_weight;
 	[Widget] Gtk.Label extra_window_jumps_label_cm;
-	[Widget] Gtk.Label extra_window_jumps_label_dj_arms;
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_arms;
-	[Widget] Gtk.Label extra_window_label_jumps_no_options;
 
 	//slCMJ	
-	[Widget] Gtk.Box vbox_extra_window_jumps_single_leg;
-	[Widget] Gtk.Box vbox_extra_window_jumps_single_leg_radios;
-	[Widget] Gtk.Frame frame_extra_window_jumps_single_leg_input;
+	[Widget] Gtk.Box hbox_extra_window_jumps_single_leg_radios;
+	[Widget] Gtk.Notebook notebook_options_after_execute;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_vertical;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_horizontal;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_single_leg_mode_lateral;
@@ -1014,7 +1010,6 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.Label extra_window_jumps_rj_label_weight;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_fall;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_cm;
-	[Widget] Gtk.Label extra_window_label_jumps_rj_no_options;
 	[Widget] Gtk.CheckButton checkbutton_allow_finish_rj_after_time;
 
 	
@@ -1057,13 +1052,32 @@ partial class ChronoJumpWindow
 	}
 
 
-	private void on_extra_window_jumps_radio_dj_fall_calculate_toggled (object o, EventArgs args) {
-		extra_window_jumps_label_dj_start_inside.Visible = true;
-		extra_window_jumps_label_dj_start_outside.Visible = false;
-	}
-	private void on_extra_window_jumps_radio_dj_fall_predefined_toggled (object o, EventArgs args) {
-		extra_window_jumps_label_dj_start_inside.Visible = false;
-		extra_window_jumps_label_dj_start_outside.Visible = true;
+	/*
+	 * when pre-jump from inside, dj fall is calculated
+	 * when fall down from outside, the dj fall is predefined
+	 */
+	private void on_extra_window_jumps_check_dj_fall_calculate_toggled (object o, EventArgs args) 
+	{
+		bool calculate = extra_window_jumps_check_dj_fall_calculate.Active;
+
+		extra_windows_jumps_image_dj_fall_calculate.Visible = calculate;
+		extra_window_jumps_label_dj_start_inside.Visible = calculate;
+		
+		extra_windows_jumps_image_dj_fall_predefined.Visible = ! calculate;
+		extra_window_jumps_label_dj_start_outside.Visible = ! calculate;
+		hbox_extra_window_jumps_fall_height.Visible = ! calculate;
+
+		if(calculate) {
+			if(extra_window_jumps_check_dj_arms.Active) 
+				changeTestImage("","", "jump_dj_a_inside.png");
+			else
+				changeTestImage("","", "jump_dj_inside.png");
+		} else {
+			if(extra_window_jumps_check_dj_arms.Active) 
+				changeTestImage("","", "jump_dj_a.png");
+			else
+				changeTestImage("","", "jump_dj.png");
+		}
 	}
 	
 	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
@@ -1107,16 +1121,13 @@ partial class ChronoJumpWindow
 	{
 		currentEventType = myJumpType;
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
-		bool hasOptions = false;
-	
+
 		if(myJumpType.HasWeight) {
-			hasOptions = true;
 			extra_window_showWeightData(myJumpType, true);	
 		} else 
 			extra_window_showWeightData(myJumpType, false);	
 
 		if(myJumpType.HasFall) {
-			hasOptions = true;
 			extra_window_showFallData(myJumpType, true);
 		} else
 			extra_window_showFallData(myJumpType, false);	
@@ -1128,11 +1139,16 @@ partial class ChronoJumpWindow
 			else //myJumpType.Name == "DJna"
 				extra_window_jumps_check_dj_arms.Active = false;
 
-			hasOptions = true;
 			extra_window_showTechniqueArmsData(true, false); //visible, sensitive
+		
+			if(extra_window_jumps_check_dj_fall_calculate.Active) {
+				if(extra_window_jumps_check_dj_arms.Active) 
+					changeTestImage("","", "jump_dj_a_inside.png");
+				else
+					changeTestImage("","", "jump_dj_inside.png");
+			}
 		} else if(myJumpType.Name == "DJ") { 
 			//user has pressed DJ button
-			hasOptions = true;
 			extra_window_jumps_check_dj_arms.Active = extra_window_jumps_arms;
 
 			on_extra_window_jumps_check_dj_arms_clicked(new object(), new EventArgs());
@@ -1150,24 +1166,18 @@ partial class ChronoJumpWindow
 
 		extra_window_showSingleLegStuff(myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright");
 		if(myJumpType.Name == "slCMJleft" || myJumpType.Name == "slCMJright") {
-			hasOptions = true;
-			frame_extra_window_jumps_single_leg_input.Sensitive = false;
 			extra_window_jumps_spin_single_leg_distance.Value = 0;
 			extra_window_jumps_spin_single_leg_angle.Value = 90;
 		}
-
-		extra_window_jumps_showNoOptions(myJumpType, hasOptions);
 	}
 	
 	private void extra_window_jumps_rj_initialize(JumpType myJumpType) 
 	{
 		currentEventType = myJumpType;
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
-		bool hasOptions = false;
 		checkbutton_allow_finish_rj_after_time.Visible = false;
 	
 		if(myJumpType.FixedValue >= 0) {
-			hasOptions = true;
 			string jumpsName = Catalog.GetString("jumps");
 			string secondsName = Catalog.GetString("seconds");
 			if(myJumpType.JumpsLimited) {
@@ -1190,14 +1200,12 @@ partial class ChronoJumpWindow
 			extra_window_showLimitData (false);
 
 		if(myJumpType.HasWeight) {
-			hasOptions = true;
 			extra_window_showWeightData(myJumpType, true);	
 		} else 
 			extra_window_showWeightData(myJumpType, false);	
 
 		if(myJumpType.HasFall || myJumpType.Name == Constants.RunAnalysisName) {
 			extra_window_showFallData(myJumpType, true);	
-			hasOptions = true;
 		} else
 			extra_window_showFallData(myJumpType, false);
 		
@@ -1208,8 +1216,6 @@ partial class ChronoJumpWindow
 		} else {
 			extra_window_jumps_rj_radiobutton_weight.Active = true;
 		}
-
-		extra_window_jumps_showNoOptions(myJumpType, hasOptions);
 	}
 
 	private void on_extra_window_jumps_check_dj_arms_clicked(object o, EventArgs args)
@@ -1297,10 +1303,7 @@ partial class ChronoJumpWindow
 	}
 	
 	private void extra_window_showTechniqueArmsData (bool show, bool sensitive) {
-		extra_window_jumps_label_dj_arms.Visible = show;
 		extra_window_jumps_check_dj_arms.Visible = show;
-		
-		extra_window_jumps_label_dj_arms.Sensitive = sensitive;
 		extra_window_jumps_check_dj_arms.Sensitive = sensitive;
 	}
 	
@@ -1311,9 +1314,9 @@ partial class ChronoJumpWindow
 			extra_window_jumps_rj_label_cm.Visible = show;
 		
 			//only on simple jumps	
-			extra_window_jumps_vbox_fall.Visible = false;
+			extra_window_jumps_hbox_fall.Visible = false;
 		} else 
-			extra_window_jumps_vbox_fall.Visible = show;
+			extra_window_jumps_hbox_fall.Visible = show;
 	}
 	
 	private void extra_window_showLimitData (bool show) {
@@ -1323,18 +1326,9 @@ partial class ChronoJumpWindow
 	}
 	
 	private void extra_window_showSingleLegStuff(bool show) {
-		vbox_extra_window_jumps_single_leg.Visible = show;
+		hbox_extra_window_jumps_single_leg_radios.Visible = show;
 	}
 			
-	private void extra_window_jumps_showNoOptions(JumpType myJumpType, bool hasOptions) {
-		if(myJumpType.IsRepetitive) 
-			extra_window_label_jumps_rj_no_options.Visible = ! hasOptions;
-		else 
-			extra_window_label_jumps_no_options.Visible = ! hasOptions;
-	}
-
-
-
 	private void on_extra_window_jumps_radiobutton_kg_toggled (object o, EventArgs args)
 	{
 		extra_window_jumps_option = "Kg";
@@ -1405,7 +1399,10 @@ partial class ChronoJumpWindow
 		myTreeViewJumps.Update(currentJump);
 		
 		//sensitive slCMJ options 
-		vbox_extra_window_jumps_single_leg_radios.Sensitive = true;
+		hbox_extra_window_jumps_single_leg_radios.Sensitive = true;
+
+		//hide slCMJ distance stuff and show button execute test again
+		notebook_options_after_execute.CurrentPage = 0;
 	}
 
 }
@@ -1848,7 +1845,7 @@ public class JumpsRjMoreWindow : EventMoreWindow
 	}
 	
 	protected override string [] findTestTypesInSessions() {
-		return SqliteJumpRj.SelectJumps(-1, -1, "", selectedEventName); 
+		return SqliteJumpRj.SelectJumps(false, -1, -1, "", selectedEventName); 
 	}
 	
 	void on_button_cancel_clicked (object o, EventArgs args)
