@@ -36,15 +36,15 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_extra_window_radio_multichronopic_start;
 	[Widget] Gtk.Label label_extra_window_radio_multichronopic_run_analysis;
 
-	[Widget] Gtk.TextView extra_window_textview_multichronopic_need_two;
+	[Widget] Gtk.Label extra_window_label_multichronopic_need_two;
+	[Widget] Gtk.Button button_run_analysis_help;
 
 	[Widget] Gtk.CheckButton extra_window_check_multichronopic_sync;
 	[Widget] Gtk.CheckButton extra_window_check_multichronopic_delete_first;
 
 	//run analysis
-	[Widget] Gtk.VBox extra_window_vbox_run_analysis_total_distance;
+	[Widget] Gtk.HBox extra_window_hbox_run_analysis_total_distance;
 	[Widget] Gtk.SpinButton extra_window_spin_run_analysis_distance;
-	[Widget] Gtk.TextView extra_window_textview_run_analysis_cps_order;
 	
 	int extra_window_multichronopic_distance = 1000; //1000cm: 10m
 
@@ -68,7 +68,6 @@ public partial class ChronoJumpWindow
 		currentEventType = myMultiChronopicType;
 		changeTestImage(EventType.Types.MULTICHRONOPIC.ToString(), 
 				myMultiChronopicType.Name, myMultiChronopicType.ImageFileName);
-		bool hasOptions = false;
 
 		extra_window_spin_run_analysis_distance.Value = extra_window_multichronopic_distance;
 		bool showSyncAndDeleteFirst = false;
@@ -89,11 +88,11 @@ public partial class ChronoJumpWindow
 			can_do = false;
 
 		button_execute_test.Sensitive = can_do;
-		extra_window_textview_multichronopic_need_two.Visible = ! can_do;
+		extra_window_label_multichronopic_need_two.Visible = ! can_do;
 		
 		extra_window_check_multichronopic_sync.Sensitive = can_do;
 		extra_window_check_multichronopic_delete_first.Sensitive = can_do;
-		extra_window_vbox_run_analysis_total_distance.Sensitive = can_do;
+		extra_window_hbox_run_analysis_total_distance.Sensitive = can_do;
 	}
 
 	private void extra_window_multichronopic_showSyncAndDeleteFirst(bool show) {
@@ -101,10 +100,14 @@ public partial class ChronoJumpWindow
 		extra_window_check_multichronopic_delete_first.Visible = show;
 	}
 	private void extra_window_multichronopic_showRunDistance(bool show) {
-		extra_window_vbox_run_analysis_total_distance.Visible = show;
-		extra_window_textview_run_analysis_cps_order.Visible = show;
+		extra_window_hbox_run_analysis_total_distance.Visible = show;
+		button_run_analysis_help.Visible = show;
 	}
 
+	private void on_button_run_analysis_help_clicked (object o, EventArgs args) {
+		new DialogMessage(Constants.MessageTypes.INFO, 
+				Catalog.GetString("First Chronopic should be connected to photocells.\nSecond Chronopic to platforms.") + "\n");
+	}
 
 }
 
