@@ -892,16 +892,6 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.Label extra_window_runs_label_distance;
 	[Widget] Gtk.SpinButton extra_window_runs_spinbutton_distance;
 	[Widget] Gtk.Label extra_window_runs_label_distance_units;
-	[Widget] Gtk.Label extra_window_label_runs_no_options;
-	
-	[Widget] Gtk.Box vbox_runs_prevent_double_contact;
-	[Widget] Gtk.CheckButton checkbutton_runs_prevent_double_contact;
-	[Widget] Gtk.SpinButton spinbutton_runs_prevent_double_contact;
-	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_first;
-	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_average;
-	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_last;
-	[Widget] Gtk.RadioButton radio_runs_speed_start_arrival;
-	[Widget] Gtk.RadioButton radio_runs_speed_start_leaving;
 	
 	//options runs interval
 	[Widget] Gtk.Label extra_window_runs_interval_label_distance;
@@ -910,16 +900,6 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.Label extra_window_runs_interval_label_limit;
 	[Widget] Gtk.SpinButton extra_window_runs_interval_spinbutton_limit;
 	[Widget] Gtk.Label extra_window_runs_interval_label_limit_units;
-	[Widget] Gtk.Label extra_window_label_runs_interval_no_options;
-	
-	[Widget] Gtk.Box vbox_runs_i_prevent_double_contact;
-	[Widget] Gtk.CheckButton checkbutton_runs_i_prevent_double_contact;
-	[Widget] Gtk.SpinButton spinbutton_runs_i_prevent_double_contact;
-	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_first;
-	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_average;
-	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_last;
-	[Widget] Gtk.RadioButton radio_runs_i_speed_start_arrival;
-	[Widget] Gtk.RadioButton radio_runs_i_speed_start_leaving;
 	
 
 	double extra_window_runs_distance = 100;
@@ -988,7 +968,6 @@ partial class ChronoJumpWindow
 	{
 		currentEventType = myRunType;
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
-		bool hasOptions = false;
 
 		extra_window_runs_label_distance.Text = Catalog.GetString("Track distance (between platforms)");
 		extra_window_runs_label_distance_units.Text = Catalog.GetString("meters");
@@ -1008,24 +987,19 @@ partial class ChronoJumpWindow
 
 		}
 
-		hasOptions = true;
-		extra_window_runs_showNoOptions(myRunType, hasOptions);
 	}
 	
 	private void extra_window_runs_interval_initialize(RunType myRunType) 
 	{
 		currentEventType = myRunType;
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
-		bool hasOptions = false;
 
 		if(myRunType.Distance > 0) {
 			extra_window_runs_interval_spinbutton_distance.Value = myRunType.Distance;
 			extra_window_showDistanceData(myRunType, true, false);	//visible, sensitive
-			hasOptions = true;
 		} else if(myRunType.Distance == 0) {
 			extra_window_runs_interval_spinbutton_distance.Value = extra_window_runs_interval_distance; 
 			extra_window_showDistanceData(myRunType, true, true);	//visible, sensitive
-			hasOptions = true;
 		} else { //variableDistancesString (eg. MTGUG) don't show anything
 			extra_window_showDistanceData(myRunType, false, false);	//visible, sensitive
 		}
@@ -1045,12 +1019,9 @@ partial class ChronoJumpWindow
 				extra_window_runs_interval_spinbutton_limit.Value = extra_window_runs_interval_limit;
 				extra_window_showLimitData(true, true);	//visible, sensitive
 			}
-			hasOptions = true;
 		} else {
 			extra_window_showLimitData(false, false);	//visible, sensitive
 		}
-
-		extra_window_runs_showNoOptions(myRunType, hasOptions);
 	}
 
 	private void on_more_runs_update_test (object o, EventArgs args) {
@@ -1135,39 +1106,7 @@ partial class ChronoJumpWindow
 		extra_window_runs_interval_spinbutton_limit.Sensitive = sensitive;
 		extra_window_runs_interval_label_limit_units.Sensitive = sensitive;
 	}
-	
-	private void extra_window_runs_showNoOptions(RunType myRunType, bool hasOptions) {
-		if(myRunType.HasIntervals) 
-			extra_window_label_runs_interval_no_options.Visible = ! hasOptions;
-		else 
-			extra_window_label_runs_no_options.Visible = ! hasOptions;
-	}
 
-	protected void on_checkbutton_runs_prevent_double_contact_toggled (object o, EventArgs args) {
-		vbox_runs_prevent_double_contact.Visible = checkbutton_runs_prevent_double_contact.Active;
-	}
-	protected void on_checkbutton_runs_i_prevent_double_contact_toggled (object o, EventArgs args) {
-		vbox_runs_i_prevent_double_contact.Visible = checkbutton_runs_i_prevent_double_contact.Active;
-	}
-
-
-	bool update_sqlite_at_runs_speed_radios = false;
-	private void on_radio_runs_speed_start_toggled (object o, EventArgs args) {
-		if(update_sqlite_at_runs_speed_radios) {
-			if(radio_runs_speed_start_arrival.Active)
-				SqlitePreferences.Update("runSpeedStartArrival", "True", false);
-			else
-				SqlitePreferences.Update("runSpeedStartArrival", "False", false);
-		}
-	}
-	private void on_radio_runs_i_speed_start_toggled (object o, EventArgs args) {
-		if(update_sqlite_at_runs_speed_radios) {
-			if(radio_runs_i_speed_start_arrival.Active)
-				SqlitePreferences.Update("runISpeedStartArrival", "True", false);
-			else
-				SqlitePreferences.Update("runISpeedStartArrival", "False", false);
-		}
-	}
 }
 
 
@@ -1584,7 +1523,7 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 	}
 
 	protected override string [] findTestTypesInSessions() {
-		return SqliteRunInterval.SelectRuns(-1, -1, selectedEventName); 
+		return SqliteRunInterval.SelectRuns(false, -1, -1, selectedEventName); 
 	}
 	
 	
