@@ -38,11 +38,19 @@ public class Preferences
 	public bool weightStatsPercent;		//AKA weightPercentPreferred
 	public bool heightPreferred;
 	public bool metersSecondsPreferred;
+	public bool runSpeedStartArrival;
+
+	public Constants.DoubleContact runDoubleContactsMode; //default LAST
+	public int runDoubleContactsMS; //milliseconds
+	public Constants.DoubleContact runIDoubleContactsMode; //default AVERAGE
+	public int runIDoubleContactsMS; //milliseconds
+	
 	public bool encoderPropulsive;
 	public double encoderSmoothCon;
 	public int videoDeviceNum; 		//AKA videoDevice
 	public Constants.Encoder1RMMethod encoder1RMMethod;
 	public string CSVExportDecimalSeparator;
+	public string language;
 	public bool RGraphsTranslate;
 	public bool useHeightsOnJumpIndexes;
 	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
@@ -56,8 +64,6 @@ public class Preferences
 	public bool videoOn;
 	public int evaluatorServerID;
 	public string versionAvailable;
-	public bool runSpeedStartArrival;
-	public bool runISpeedStartArrival;
 	public string machineID;
 	public Constants.MultimediaStorage multimediaStorage;
 	public string databaseVersion;
@@ -68,7 +74,6 @@ public class Preferences
 	
 	//public string chronopicPort;
 	//public bool simulated;
-	//public string language;
 	//public double encoderSmoothEccCon; 	//unused
 	//public double inertialmomentum; 	//unused
 
