@@ -76,7 +76,7 @@ public class TreeViewJumps : TreeViewEvent
 		columnsString = obtainColumnsString(columnsStringPre);
 	
 
-		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidded). 
+		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidden). 
 		store = getStore(columnsString.Length +1); //+1 because, eventID is not show in last col
 		treeview.Model = store;
 		prepareHeaders(columnsString);
@@ -160,18 +160,11 @@ public class TreeViewJumps : TreeViewEvent
 		myJump.Description = myStringOfData[9].ToString();
 		myJump.Simulated = Convert.ToInt32(myStringOfData[11].ToString());
 
+		myJump.Weight = Convert.ToDouble(myStringOfData[8].ToString());
+
 		//to calculate potency
 		personWeight = Convert.ToDouble(myStringOfData[12]);
-		weightInKg = Util.WeightFromPercentToKg(
-				Convert.ToDouble(myStringOfData[8]), 
-				personWeight);
-
-		//we create the jump with a weight of percent or kk
-		if(preferences.weightStatsPercent)
-			myJump.Weight = Convert.ToDouble(myStringOfData[8].ToString());
-		else
-			myJump.Weight = weightInKg;
-
+		weightInKg = Util.WeightFromPercentToKg(myJump.Weight, personWeight);
 
 		return myJump;
 	}
@@ -191,7 +184,15 @@ public class TreeViewJumps : TreeViewEvent
 		myData[count++] = Util.TrimDecimals(newJump.Tc.ToString(), pDN);
 		myData[count++] = Util.TrimDecimals(newJump.Tv.ToString(), pDN);
 		
-		myData[count++] = Util.TrimDecimals(newJump.Weight.ToString(), pDN);
+		//we calculate weightInKg again because can be changed in edit jump, and then treeview is no re-done
+		//but we do not calculate again person weight, because if it changes treeview is created again
+		//
+		//Also this is needed on Add (where personWeight is passed using PersonWeight, but not weightInKg)
+		weightInKg = Util.WeightFromPercentToKg(
+				Convert.ToDouble(newJump.Weight.ToString()),
+				personWeight);
+		
+		myData[count++] = Util.TrimDecimals(weightInKg.ToString(), pDN);
 
 		myData[count++] = Util.TrimDecimals(newJump.Fall.ToString(), pDN);
 		myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(newJump.Tv.ToString()), pDN);
@@ -202,12 +203,6 @@ public class TreeViewJumps : TreeViewEvent
 			//takeoff has no tv. power should not be calculated
 			//calculate jumps with tf
 			if(newJump.Tv > 0) {	
-				//we calculate weightInKg again because can be changed in edit jump, and then treeview is no re-done
-				//but we do not calculate again person weight, because if it changes treeview is created again
-				weightInKg = Util.WeightFromPercentToKg(
-						Convert.ToDouble(newJump.Weight.ToString()),
-						personWeight);
-				
 				if(newJump.Tc > 0) 	//if it's Dj (has tf, and tc)
 					myData[count++] = Util.TrimDecimals(
 							Util.GetDjPower(newJump.Tc, newJump.Tv, (personWeight + weightInKg), newJump.Fall).ToString(), 1);
@@ -272,7 +267,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 	       	};
 		columnsString = obtainColumnsString(columnsStringPre);
 
-		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidded). 
+		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidden). 
 		store = getStore(columnsString.Length +1); //+1 because, eventID is not show in last col
 		treeview.Model = store;
 		prepareHeaders(columnsString);
@@ -289,16 +284,10 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myJumpRj.Description = myStringOfData[9].ToString();
 		myJumpRj.Simulated = Convert.ToInt32(myStringOfData[18].ToString());
 		
-		personWeight = Convert.ToDouble(myStringOfData[19]);
-		weightInKg = Util.WeightFromPercentToKg(
-				Convert.ToDouble(myStringOfData[8]), 
-				personWeight);
+		myJumpRj.Weight = Convert.ToDouble(myStringOfData[8].ToString());
 
-		//we create the jump with a weight of percent or kk
-		if(preferences.weightStatsPercent)
-			myJumpRj.Weight = Convert.ToDouble(myStringOfData[8].ToString());
-		else
-			myJumpRj.Weight = Util.WeightFromPercentToKg(Convert.ToDouble(myStringOfData[8]), Convert.ToDouble(myStringOfData[19]));
+		personWeight = Convert.ToDouble(myStringOfData[19]);
+		weightInKg = Util.WeightFromPercentToKg(myJumpRj.Weight, personWeight);
 
 		return myJumpRj;
 	}
@@ -323,7 +312,10 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myData[count++] = "";
 		myData[count++] = "";
 		
-		myData[count++] = Util.TrimDecimals(newJumpRj.Weight.ToString(), pDN);
+		weightInKg = Util.WeightFromPercentToKg(
+				Convert.ToDouble(newJumpRj.Weight.ToString()),
+				personWeight);
+		myData[count++] = Util.TrimDecimals(weightInKg.ToString(), pDN);
 
 		myData[count++] = Util.TrimDecimals(newJumpRj.Fall.ToString(), pDN);
 		myData[count++] = ""; //height
@@ -370,6 +362,12 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myData[count++] = ""; 
 		myData[count++] = ""; 
 		myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(thisTv), pDN);
+		
+		//This is needed on Add (where personWeight is passed using PersonWeight, but not weightInKg)
+		weightInKg = Util.WeightFromPercentToKg(
+				Convert.ToDouble(newJumpRj.Weight.ToString()),
+				personWeight);
+		
 		if (preferences.showPower) {
 			double myFall;
 			if(lineCount == 0)
