@@ -41,7 +41,7 @@ public class TreeViewPulses : TreeViewEvent
 		dataLineNamePosition = 0; //position of name in the data to be printed
 		dataLineTypePosition = 4; //position of type in the data to be printed
 		allEventsName = Constants.AllPulsesName;
-		eventIDColumn = 5; //column where the uniqueID of event will be (and will be hidded)
+		eventIDColumn = 5; //column where the uniqueID of event will be (and will be hidden)
 		
 		string jumperName = Catalog.GetString("Person");
 		string timeName = Catalog.GetString("Time") + "\n(s)";
