@@ -50,7 +50,7 @@ public class TreeViewReactionTimes : TreeViewEvent
 
 		columnsString = new string[]{personName, Catalog.GetString("Time") + " (s)", descriptionName};
 
-		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidded). 
+		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidden). 
 		store = getStore(columnsString.Length +1); //+1 because, eventID is not show in last col
 		treeview.Model = store;
 		prepareHeaders(columnsString);
