@@ -660,7 +660,7 @@ public class Util
 		double tt = tc + tf; //totalTime
 		fallHeight = fallHeight / 100.0; //cm -> m
 		
-		return mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tt;
+		return mass * g * ( fallHeight + 1.226 * Math.Pow(tf,2) ) / (Double)tc;
 	}
 				
 	//only Lewis now
@@ -932,7 +932,15 @@ public class Util
 	}
 
 	/********** end of multimedia paths ************/
+	
 
+	/********** start of encoder paths ************/
+
+	public static string GetEncoderExportTempFileName() {
+		return Path.Combine(Path.GetTempPath(), "encoder_export.csv");
+	}
+
+	/********** end of encoder paths ************/
 
 
 	public static string GetManualDir() {
